#
# spec file for package docbook-utils
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           docbook-utils
BuildRequires:  automake
BuildRequires:  docbook-dsssl-stylesheets
BuildRequires:  openjade
BuildRequires:  perl-SGMLS
BuildRequires:  sgml-skel
Summary:        Small Wrapper Scripts for Processing DocBook Files
License:        LGPL-2.1-or-later
Group:          Productivity/Publishing/DocBook
Version:        0.6.14
Release:        240.1
Requires:       %{name}-minimal
Requires:       texlive-jadetex
Source:         https://src.fedoraproject.org/repo/pkgs/docbook-utils/%{name}-%{version}.tar.gz/6b41b18c365c01f225bc417cf632d81c/%{name}-%{version}.tar.gz
Patch0:         docbook-utils-catalog-jw.patch
Patch1:         docbook-utils-0.6.14-fix-bashisms.patch
# PATCH-FIX-TO-UPSTREAM
Patch2:         support_source_date_epoch.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The docbook-utils package is a set of a few small programs intended to
ease everyday use of technical documentation software based on the
DocBook DTD, either written in SGML or XML.

Tasks they currently accomplish are: * jw: convert SGML files to
   other formats (HTML, RTF, PostScript, PDF)

* sgmldiff: detect the differences in markup between two SGML files

%package minimal
Summary:        Small Wrapper Scripts for Processing DocBook Files
Group:          Productivity/Publishing/DocBook
Requires:       docbook-dsssl-stylesheets
Requires:       docbook_3
Requires:       docbook_4
Requires:       iso_ent
Requires:       openjade
Requires:       opensp
Requires:       perl-SGMLS
Requires:       sgml-skel

%description minimal
The docbook-utils package is a set of a few small programs intended to
ease everyday use of technical documentation software based on the
DocBook DTD, either written in SGML or XML.

Tasks they currently accomplish are: * jw: convert SGML files to
   other formats (HTML, RTF, PostScript, PDF)

* sgmldiff: detect the differences in markup between two SGML files

%prep
%setup -q
%patch0 -p1 -b .catalog
%patch1 -p1
%patch2 -p1

%build
autoreconf -i -f
%configure
make %{?_smp_mflags}

%install
make DESTDIR=$RPM_BUILD_ROOT install
mv $RPM_BUILD_ROOT/usr/doc/html/docbook* html

%files minimal
%defattr (-,root,root)
%doc README COPYING TODO html
%_bindir/docbook2html
%_bindir/docbook2man
%_bindir/docbook2rtf
%_bindir/jw
%_bindir/sgmldiff
%_bindir/docbook2txt
%dir %{_prefix}/share/sgml/docbook/utils-%{version}
%dir %{_prefix}/share/sgml/docbook/utils-%{version}/backends
%{_prefix}/share/sgml/docbook/utils-%{version}/frontends
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/html
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/man
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/rtf
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/txt
%{_prefix}/share/sgml/docbook/utils-%{version}/docbook-utils.dsl
%{_prefix}/share/sgml/docbook/utils-%{version}/helpers

%files
%defattr (-,root,root)
%_bindir/docbook2ps
%_bindir/docbook2dvi
%_bindir/docbook2pdf
%_bindir/docbook2tex
%_bindir/docbook2texi
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/tex
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/texi
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/dvi
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/ps
%{_prefix}/share/sgml/docbook/utils-%{version}/backends/pdf
%{_mandir}/man?/*

%changelog
* Mon Nov 27 2023 Jiri Srain <jsrain@suse.com>
- fix the download URL
* Sat Jan 21 2017 bwiedemann@suse.com
- Add support_source_date_epoch.patch to allow for reproducible builds
  of depending packages like freerdp
* Sun Oct 19 2014 Led <ledest@gmail.com>
- fix bashisms of jw script
- add patches:
  * docbook-utils-0.6.14-fix-bashisms.patch
* Wed Apr 18 2012 coolo@suse.com
- split out the backends that do not require tex to work
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Tue Dec 22 2009 jengelh@medozas.de
- enable parallel build
* Mon Mar 17 2008 werner@suse.de
- Use texlive-jadetex instead of jadetex
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 26 2004 ke@suse.de
- Require 'jadetex'; reported by Philipp Thomas [#48577].
* Mon Nov  8 2004 ke@suse.de
- Prepend ':' to the list of SGML_EXTRA_CATALOGS to make sure
  SGML_CATALOG_FILES are always properly separated; reported by Ruediger
  Oertel.
* Mon Nov  8 2004 ke@suse.de
- Fix problem with finding XML related catalogs; reported by Kerry Cox
  [# 48020].
* Thu Feb 12 2004 ke@suse.de
- Update to version 0.6.14: bugfixes, use w3m als fallback for text
  generation.
* Thu Jan 15 2004 ke@suse.de
- Update to version 0.6.13.
* Thu Jun 12 2003 coolo@suse.de
- package dirs too
* Mon May 19 2003 coolo@suse.de
- package docs too
* Mon Apr 16 2001 adrian@suse.de
- created package
